@@ -1,6 +1,7 @@
 import subprocess
 import sys
 import importlib
+from bs4 import BeautifulSoup
 DOCKER_IMAGE_NAME = "styczynski/eniam:0.1.1"
 
 from .eniam_syntax import SUPPORTED_VALUES
@@ -129,9 +130,61 @@ class MultiprocessDomparserResult():
     def _call_dom(self, opts):
         return self.inst._exec_dom_opt(opts).html()
 
+    def show(self):
+        display = importlib.import_module("IPython.core.display")
+        display.display(display.HTML(self.html()))
+
     def html(self):
         pool = Pool()
-        return pool.map(self._call_dom, list(map(lambda sentence: [sentence, self.opts], self.input)))
+        output_htmls = pool.map(self._call_dom, list(map(lambda sentence: [sentence, self.opts], self.input)))
+        chunks = []
+
+        index = -1
+        for output_html in output_htmls:
+            index = index+1
+            soup = BeautifulSoup(output_html[0])
+            body = soup.find('body')
+            body_contents = str(body.findChildren(recursive=False)[0])
+            wrapped_result = f"""
+            <li>
+                <div>
+                    <i>{self.input[index]}</i>
+                </div>
+                <div>
+                    <table>
+                        <tr>
+                            <th>Property</th>
+                            <th>Value</th>
+                        </tr>
+                        <tr>
+                            <td>Input sentence</td>
+                            <td>{self.input[index]}</td>
+                        </tr>
+                    </table>
+                </div>
+                <div>
+                    {body_contents}
+                </div>
+            </li>
+            """
+            chunks.append(wrapped_result)
+
+        chunks_str = '\n'.join(chunks)
+        return f"""
+            <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+            <html>
+                <head>
+                    <META HTTP-EQUIV="CONTENT-TYPE" CONTENT="text/html; charset=utf8">
+                    <TITLE>ENIAM: Kategorialny Parser Składniowo-Semantyczny</TITLE>
+                    <META HTTP-EQUIV="Content-Language" CONTENT="pl">
+                </head>
+                <body>
+                    <ul>
+                        {chunks_str}
+                    </ul>
+                </body>
+        """
+
 
 class DomparserResult():
     def __init__(self, html_content, output_pdfs, output_pngs, file_map):
